
From: Adrian Bunk <bunk@stusta.de>

This patch makes some needlessly global code static.

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/scsi/hosts.c      |    2 +-
 drivers/scsi/scsi.c       |    6 ++++--
 drivers/scsi/scsi_debug.c |    2 +-
 drivers/scsi/scsi_lib.c   |    2 +-
 drivers/scsi/scsi_priv.h  |    4 ----
 drivers/scsi/scsi_sysfs.c |    4 ++--
 6 files changed, 9 insertions(+), 11 deletions(-)

diff -puN drivers/scsi/hosts.c~scsi-make-code-static drivers/scsi/hosts.c
--- 25/drivers/scsi/hosts.c~scsi-make-code-static	2005-05-23 19:42:42.000000000 -0700
+++ 25-akpm/drivers/scsi/hosts.c	2005-05-23 19:42:42.000000000 -0700
@@ -56,7 +56,7 @@ static struct class shost_class = {
  * @shost:	pointer to struct Scsi_Host
  * recovery:	recovery requested to run.
  **/
-void scsi_host_cancel(struct Scsi_Host *shost, int recovery)
+static void scsi_host_cancel(struct Scsi_Host *shost, int recovery)
 {
 	struct scsi_device *sdev;
 
diff -puN drivers/scsi/scsi.c~scsi-make-code-static drivers/scsi/scsi.c
--- 25/drivers/scsi/scsi.c~scsi-make-code-static	2005-05-23 19:42:42.000000000 -0700
+++ 25-akpm/drivers/scsi/scsi.c	2005-05-23 19:42:42.000000000 -0700
@@ -68,6 +68,8 @@
 #include "scsi_priv.h"
 #include "scsi_logging.h"
 
+static void scsi_done(struct scsi_cmnd *cmd);
+static int scsi_retry_command(struct scsi_cmnd *cmd);
 
 /*
  * Definitions and constants.
@@ -741,7 +743,7 @@ static DEFINE_PER_CPU(struct list_head, 
  *
  * This function is interrupt context safe.
  */
-void scsi_done(struct scsi_cmnd *cmd)
+static void scsi_done(struct scsi_cmnd *cmd)
 {
 	/*
 	 * We don't have to worry about this one timing out any more.
@@ -836,7 +838,7 @@ static void scsi_softirq(struct softirq_
  *              level drivers should not become re-entrant as a result of
  *              this.
  */
-int scsi_retry_command(struct scsi_cmnd *cmd)
+static int scsi_retry_command(struct scsi_cmnd *cmd)
 {
 	/*
 	 * Restore the SCSI command state.
diff -puN drivers/scsi/scsi_debug.c~scsi-make-code-static drivers/scsi/scsi_debug.c
--- 25/drivers/scsi/scsi_debug.c~scsi-make-code-static	2005-05-23 19:42:42.000000000 -0700
+++ 25-akpm/drivers/scsi/scsi_debug.c	2005-05-23 19:42:42.000000000 -0700
@@ -1783,7 +1783,7 @@ static void __exit scsi_debug_exit(void)
 device_initcall(scsi_debug_init);
 module_exit(scsi_debug_exit);
 
-void pseudo_0_release(struct device * dev)
+static void pseudo_0_release(struct device * dev)
 {
 	if (SCSI_DEBUG_OPT_NOISE & scsi_debug_opts)
 		printk(KERN_INFO "scsi_debug: pseudo_0_release() called\n");
diff -puN drivers/scsi/scsi_lib.c~scsi-make-code-static drivers/scsi/scsi_lib.c
--- 25/drivers/scsi/scsi_lib.c~scsi-make-code-static	2005-05-23 19:42:42.000000000 -0700
+++ 25-akpm/drivers/scsi/scsi_lib.c	2005-05-23 19:42:42.000000000 -0700
@@ -44,7 +44,7 @@ struct scsi_host_sg_pool {
 #endif
 
 #define SP(x) { x, "sgpool-" #x } 
-struct scsi_host_sg_pool scsi_sg_pools[] = { 
+static struct scsi_host_sg_pool scsi_sg_pools[] = {
 	SP(8),
 	SP(16),
 	SP(32),
diff -puN drivers/scsi/scsi_priv.h~scsi-make-code-static drivers/scsi/scsi_priv.h
--- 25/drivers/scsi/scsi_priv.h~scsi-make-code-static	2005-05-23 19:42:42.000000000 -0700
+++ 25-akpm/drivers/scsi/scsi_priv.h	2005-05-23 19:42:42.000000000 -0700
@@ -61,8 +61,6 @@ extern void scsi_exit_hosts(void);
 extern int scsi_dispatch_cmd(struct scsi_cmnd *cmd);
 extern int scsi_setup_command_freelist(struct Scsi_Host *shost);
 extern void scsi_destroy_command_freelist(struct Scsi_Host *shost);
-extern void scsi_done(struct scsi_cmnd *cmd);
-extern int scsi_retry_command(struct scsi_cmnd *cmd);
 extern int scsi_insert_special_req(struct scsi_request *sreq, int);
 extern void scsi_init_cmd_from_req(struct scsi_cmnd *cmd,
 		struct scsi_request *sreq);
@@ -136,7 +134,6 @@ extern void scsi_exit_sysctl(void);
 #endif /* CONFIG_SYSCTL */
 
 /* scsi_sysfs.c */
-extern void scsi_device_dev_release(struct device *);
 extern int scsi_sysfs_add_sdev(struct scsi_device *);
 extern int scsi_sysfs_add_host(struct Scsi_Host *);
 extern int scsi_sysfs_register(void);
@@ -145,7 +142,6 @@ extern void scsi_sysfs_device_initialize
 extern int scsi_sysfs_target_initialize(struct scsi_device *);
 extern struct scsi_transport_template blank_transport_template;
 
-extern struct class sdev_class;
 extern struct bus_type scsi_bus_type;
 
 /* 
diff -puN drivers/scsi/scsi_sysfs.c~scsi-make-code-static drivers/scsi/scsi_sysfs.c
--- 25/drivers/scsi/scsi_sysfs.c~scsi-make-code-static	2005-05-23 19:42:42.000000000 -0700
+++ 25-akpm/drivers/scsi/scsi_sysfs.c	2005-05-23 19:42:42.000000000 -0700
@@ -150,7 +150,7 @@ static void scsi_device_cls_release(stru
 	put_device(&sdev->sdev_gendev);
 }
 
-void scsi_device_dev_release(struct device *dev)
+static void scsi_device_dev_release(struct device *dev)
 {
 	struct scsi_device *sdev;
 	struct device *parent;
@@ -185,7 +185,7 @@ void scsi_device_dev_release(struct devi
 		put_device(parent);
 }
 
-struct class sdev_class = {
+static struct class sdev_class = {
 	.name		= "scsi_device",
 	.release	= scsi_device_cls_release,
 };
_
